import tomopy, time as t
import numpy as np

def timeit(func, named_args, kwargs):
    t0 = t.time()
    r = func(*named_args, **kwargs)
    t1 = t.time()
    return (t1 - t0, r)

prep_time, obj = timeit(np.random.randn, (377, 377, 377), dict())
ang = tomopy.angles(240) # Generate uniformly spaced tilt angles.

print("Preparation    time: {0:.3f}".format(prep_time))

proj_time, sim = timeit(tomopy.project, (obj, ang), dict()) # Calculate projections.

print("Projection     time: {0:.3f}".format(proj_time))

recon_time, rec = timeit(tomopy.recon, (sim, ang), dict(algorithm='gridrec', ncore=2)) # Reconstruct object.

print("Reconstruction time: {0:.3f}".format(recon_time))

